@@ -57,22 +57,41 @@ class Download(io.BytesIO):
                  headers,
                  chunk_size: int
                  ):
-        self.__res = get(path, auth, headers, params)
-        check_response(self.__res)
+        self.__res = None
         self._chunk_size = chunk_size
+        self._path = path
+        self._auth = auth
+        self._params = params
+        self._headers = headers
         self._iter = None
         self._buff = bytearray(0)
-        super().__init__(self.__res.content)
+        super().__init__()
+
+    def __init_request(self):
+        if self.__res is None:
+            self.__res = get(
+                self._path,
+                self._auth,
+                self._headers,
+                self._params
+            )
+            check_response(self.__res)
+
+    def getvalue(self) -> bytes:
+        self.__init_request()
+        return self.__res.content
 
     def __init_generator(self):
-        self._iter = self.__res.iter_content(self._chunk_size)
+        self.__init_request()
+        if self._iter is None:
+            self._iter = self.__res.iter_content(self._chunk_size)
 
     def read(self, *args, **kwargs):
+        self.__init_request()
         if not check_args(*args):
             with self.__res as resp:
                 return resp.content
-        if self._iter is None:
-            self.__init_generator()
+        self.__init_generator()
         try:
             self._buff.extend(bytearray(next(self._iter)))
             res = self._buff[0:args[0]]
@@ -200,11 +219,15 @@ class DrbHttpNode(AbstractNode):
         """
         if self.has_impl(impl):
             headers = None
-            if 'start' in kwargs and 'end' in kwargs:
-                headers = {'Range': 'bytes=%d-%d' % (
-                    kwargs.get('start'),
-                    kwargs.get('end')
-                )}
+            if 'start' in kwargs:
+                if 'end' in kwargs:
+                    headers = {
+                        "range":
+                            f"bytes={kwargs.get('start')}"
+                            f"-{kwargs.get('start') + kwargs.get('end')}"}
+                else:
+                    headers = {"range": f"bytes={kwargs.get('start')}-"}
+
             return Download(self.path.name,
                             self._auth,
                             self.params,
